==> esATAC_1.0.6.tar.gz: esATAC/inst/doc/esATAC-Introduction.R <==
## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, warning=FALSE, message=FALSE)

## ----flowchart,message=FALSE,warning=FALSE-------------------------------
library(esATAC)
printMap()

## ----querymannual0,message=FALSE,warning=FALSE---------------------------
?SamToBed

## ----querymannual,message=FALSE,warning=FALSE----------------------------
?atacSamToBed

## ----querymannual1,message=FALSE,warning=FALSE---------------------------
?samToBed

## ----installpkg,eval=FALSE,message=FALSE,warning=FALSE-------------------
#  source("http://www.bioconductor.org/biocLite.R")
#  biocLite("esATAC")

## ----loading0,message=FALSE----------------------------------------------
library(esATAC)

## ----loading1,message=FALSE----------------------------------------------
options(java.parameters = "-Xmx8000m")

## ----loadingpkg,message=FALSE--------------------------------------------
library(magrittr)
library(BSgenome.Hsapiens.UCSC.hg19)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(org.Hs.eg.db)
library(R.utils)

## ----loadref, eval=TRUE--------------------------------------------------
# we use temp directiory "td" here 
# Change it to your directiory because the intermediate file may be huge
td<-tempdir()
options(atacConf=setConfigure("tmpdir",td))
options(atacConf=setConfigure("threads",8))

## ----config, eval=TRUE---------------------------------------------------
#uncomment and modify to run:
#options(atacConf=setConfigure("refdir","path/to/refdatafolder"))
#options(atacConf=setConfigure("genome","hg19"))

## ----casecontrol, eval=FALSE---------------------------------------------
#  library(esATAC)
#  
#  # create a directory if refdir is not exist
#  dir.create(file.path(tempdir(),"ref"))
#  
#  # call pipeline
#  # for overall example(all human motif in JASPAR will be processed)
#  conclusion <-
#      atacPipe2(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          case=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#                    fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz")),
#  # MODIFY: Change these paths to your own control files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          control=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2"),
#                       fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19")
#  

## ----casesingle, eval=FALSE----------------------------------------------
#  library(esATAC)
#  
#  # create a directory if refdir is not exist
#  dir.create(file.path(tempdir(),"ref"))
#  
#  # call pipeline
#  # for overall example(all human motif in JASPAR will be processed)
#  conclusion <-
#      atacPipe(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#          fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz"),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19")

## ----motifsetex,eval=FALSE-----------------------------------------------
#  
#  ### case-control
#  
#  # for a quick example(only 3 motif will be processed)
#  pfm_file <- system.file("extdata", "motif.txt", package="esATAC")
#  pwm <- PWMFromFile(motif.file = pfm_file, is.PWM = FALSE)
#  
#  
#  conclusion2 <-
#      atacPipe2(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          case=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#                    fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz")),
#  # MODIFY: Change these paths to your own control files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          control=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2"),
#                       fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19",
#          motifPWM = pwm)
#  
#  
#  ### single sample
#  
#  # for a quick example(only 3 motif will be processed)
#  pfm_file <- system.file("extdata", "motif.txt", package="esATAC")
#  pwm <- PWMFromFile(motif.file = pfm_file, is.PWM = FALSE)
#  
#  conclusion <-
#      atacPipe(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#          fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz"),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19",
#          motifPWM = pwm)
#  
#  

## ----Preprocess, warning = FALSE, results = 'hide', message = FALSE------
# Identify adapters
prefix<-system.file(package="esATAC", "extdata", "uzmg")
(reads_1 <-file.path(prefix,"m1",dir(file.path(prefix,"m1"))))
(reads_2 <-file.path(prefix,"m2",dir(file.path(prefix,"m2"))))

reads_merged_1 <- file.path(td,"reads1.fastq")
reads_merged_2 <- file.path(td,"reads2.fastq")
atacproc <- 
atacUnzipAndMerge(fastqInput1 = reads_1,fastqInput2 = reads_2) %>%
atacRenamer %>% atacRemoveAdapter

## ----adrmhelp------------------------------------------------------------
library(Rbowtie2)
adapterremoval_usage()

## ----Mapping, warning = FALSE, results = 'hide', message = FALSE---------
## Building a bowtie2 index
library("Rbowtie2")
refs <- dir(system.file(package="esATAC", "extdata", "bt2","refs"),
full=TRUE)
bowtie2_build(references=refs, bt2Index=file.path(td, "lambda_virus"),
"--threads 4 --quiet",overwrite=TRUE)
## Alignments
reads_1 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_1.fastq")
reads_2 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_2.fastq")
if(file.exists(file.path(td, "lambda_virus.1.bt2"))){
    (bowtie2Mapping(bt2Idx = file.path(td, "lambda_virus"),
       samOutput = file.path(td, "result.sam"),
       fastqInput1=reads_1,fastqInput2=reads_2,threads=3))
    head(readLines(file.path(td, "result.sam")))
}

## ----bt2help-------------------------------------------------------------
library(Rbowtie2)
bowtie2_usage()

## ----Convert, warning = FALSE, results = 'hide', message = FALSE---------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBed(samInput = samfile) 

## ----FiltCalling, warning = FALSE, results = 'hide', message = FALSE-----
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling


## ----echo = TRUE, results = 'hide', message = FALSE----------------------
## extract example peak file from package "esATAC"
p1bz <- system.file("extdata", "Example_peak1.bed.bz2", package="esATAC")
peak1_path <- as.vector(bunzip2(filename = p1bz,
destname = file.path(getwd(), "Example_peak1.bed"),
ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
## run peakanno to annotate peaks
AnnoInfo <- peakanno(peakInput = peak1_path, TxDb = TxDb.Hsapiens.UCSC.hg19.knownGene, annoDb = "org.Hs.eg.db")

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
library(ChIPseeker)

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
peakanno <- getReportVal(AnnoInfo, "annoOutput.rds")
plotAnnoPie(x = peakanno)

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
peakanno <- as.data.frame(peakanno)
colnames(peakanno)[1] <- "chromatin"
peakanno <- subset(peakanno, select=c("chromatin", "start", "end", 
                                      "annotation", "geneStart", "geneEnd", 
                                      "geneId", "distanceToTSS", "SYMBOL"))
knitr::kable(peakanno[1:5, ])

## ----eval = TRUE, echo = TRUE, results = 'hide', message = FALSE---------
## extract gene ID
library(clusterProfiler)
data(geneList)
geneId <- names(geneList)[1:100]
## do GO analysis
goAna <- goanalysis(gene = geneId, OrgDb = "org.Hs.eg.db", keytype = "ENTREZID", ont = "MF")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
go_path <- getReportVal(goAna, "goOutput")
go_data <- read.table(file = go_path, header = TRUE, sep = "\t")
go_data <- subset(go_data, select = c("ID", "Description", "GeneRatio", "pvalue", "qvalue"))
knitr::kable(go_data[1:5, ])

## ----eval=TRUE, echo=TRUE, warning=FALSE---------------------------------
pwm <- readRDS(system.file("extdata", "motifPWM.rds", package="esATAC"))

pwm

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  sample.path <- system.file("extdata", "chr20_sample_peak.bed.bz2", package="esATAC")
#  sample.path <- as.vector(bunzip2(filename = sample.path,
#  destname = file.path(getwd(), "chr20_sample_peak.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  motif.data <- motifscan(peak = sample.path, genome = BSgenome.Hsapiens.UCSC.hg19,
#  motifPWM = pwm, prefix = "test")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
CTCF.df <- data.frame(chromatin = c("chr20", "chr20", "chr20", "chr20"),
                      start = c("189774", "239773", "247783", "281074"), 
                      end = c("189792", "239791", "247801", "281092"), 
                      strand = c("+", "+", "-", "-"),
                      score = c("0.8794931", "0.9003697", "0.9337214", "0.8511201"), 
                      sequence = c("ACTCCTCTAGAGGGTGCTC", "TTGCCACTGGGGGGAGACA",
                      "CTGCCGGCAGATGGCGGTA", "TTGCCTGCAGGGGTGGGAA"))
knitr::kable(CTCF.df)

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  ## extract cut site position from bed file
#  fra_path <- system.file("extdata", "chr20.50000.bed.bz2", package="esATAC")
#  frag <- as.vector(bunzip2(filename = fra_path,
#  destname = file.path(getwd(), "chr20.50000.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  cs.data <- extractcutsite(bedInput = frag, prefix = "ATAC")

## ----eval=FALSE, echo=TRUE, warning=FALSE, results='hide', message=FALSE----
#  fp <- atacCutSiteCount(atacProcCutSite = cs.data, atacProcMotifScan = motif.data)

## ----printmap, warning=FALSE, message=FALSE------------------------------
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

peakproc <-bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling 

peakproc %>%  printMap


## ----qpara, warning=FALSE, message=FALSE---------------------------------
#query all of available parameters
getParamItems(peakproc)

## ----getpara, warning=FALSE, message=FALSE-------------------------------
#query a parameter value
getParam(peakproc,"fragmentSize")


## ----getReport, warning=FALSE, results='hide', message=FALSE-------------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBedProc<-samToBed(samInput = samfile)

## ----getReport1,message=FALSE--------------------------------------------
getReportItems(samToBedProc)

## ----getReport2,message=FALSE--------------------------------------------
#query a parameter value
getReportVal(samToBedProc,"report")


## ----clearcache, warning=FALSE, results='hide', message=FALSE------------
clearProcCache(peakproc)
process(peakproc)

## ----session-------------------------------------------------------------
sessionInfo()

==> esATAC_1.0.7.tar.gz: esATAC/inst/doc/esATAC-Introduction.R <==
## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, warning=FALSE, message=FALSE)

## ----flowchart,message=FALSE,warning=FALSE-------------------------------
library(esATAC)
printMap()

## ----querymannual0,message=FALSE,warning=FALSE---------------------------
?SamToBed

## ----querymannual,message=FALSE,warning=FALSE----------------------------
?atacSamToBed

## ----querymannual1,message=FALSE,warning=FALSE---------------------------
?samToBed

## ----installpkg,eval=FALSE,message=FALSE,warning=FALSE-------------------
#  source("http://www.bioconductor.org/biocLite.R")
#  biocLite("esATAC")

## ----loading0,message=FALSE----------------------------------------------
library(esATAC)

## ----loading1,message=FALSE----------------------------------------------
options(java.parameters = "-Xmx8000m")

## ----loadingpkg,message=FALSE--------------------------------------------
library(magrittr)
library(BSgenome.Hsapiens.UCSC.hg19)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(org.Hs.eg.db)
library(R.utils)

## ----loadref, eval=TRUE--------------------------------------------------
# we use temp directiory "td" here 
# Change it to your directiory because the intermediate file may be huge
td<-tempdir()
options(atacConf=setConfigure("tmpdir",td))
options(atacConf=setConfigure("threads",8))

## ----config, eval=TRUE---------------------------------------------------
#uncomment and modify to run:
#options(atacConf=setConfigure("refdir","path/to/refdatafolder"))
#options(atacConf=setConfigure("genome","hg19"))

## ----casecontrol, eval=FALSE---------------------------------------------
#  library(esATAC)
#  
#  # create a directory if refdir is not exist
#  dir.create(file.path(tempdir(),"ref"))
#  
#  # call pipeline
#  # for overall example(all human motif in JASPAR will be processed)
#  conclusion <-
#      atacPipe2(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          case=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#                    fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz")),
#  # MODIFY: Change these paths to your own control files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          control=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2"),
#                       fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19")
#  

## ----casesingle, eval=FALSE----------------------------------------------
#  library(esATAC)
#  
#  # create a directory if refdir is not exist
#  dir.create(file.path(tempdir(),"ref"))
#  
#  # call pipeline
#  # for overall example(all human motif in JASPAR will be processed)
#  conclusion <-
#      atacPipe(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#          fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz"),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19")

## ----motifsetex,eval=FALSE-----------------------------------------------
#  
#  ### case-control
#  
#  # for a quick example(only 3 motif will be processed)
#  pfm_file <- system.file("extdata", "motif.txt", package="esATAC")
#  pwm <- getMotifPWM(motif.file = pfm_file, is.PWM = FALSE)
#  
#  
#  conclusion2 <-
#      atacPipe2(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          case=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#                    fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz")),
#  # MODIFY: Change these paths to your own control files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          control=list(fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2"),
#                       fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19",
#          motifPWM = pwm)
#  
#  
#  ### single sample
#  
#  # for a quick example(only 3 motif will be processed)
#  pfm_file <- system.file("extdata", "motif.txt", package="esATAC")
#  pwm <- getMotifPWM(motif.file = pfm_file, is.PWM = FALSE)
#  
#  conclusion <-
#      atacPipe(
#  # MODIFY: Change these paths to your own case files!
#  # e.g. fastqInput1 = "your/own/data/path.fastq"
#          fastqInput1 = system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#          fastqInput2 = system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz"),
#  # MODIFY: Change this path to an permanent path to be used in future!
#  # e.g refdir <- "your/own/reference/path"
#          refdir = file.path(tempdir(),"ref"),
#  # MODIFY: Set the genome for your data
#          genome = "hg19",
#          motifPWM = pwm)
#  
#  

## ----Preprocess, warning = FALSE, results = 'hide', message = FALSE------
# Identify adapters
prefix<-system.file(package="esATAC", "extdata", "uzmg")
(reads_1 <-file.path(prefix,"m1",dir(file.path(prefix,"m1"))))
(reads_2 <-file.path(prefix,"m2",dir(file.path(prefix,"m2"))))

reads_merged_1 <- file.path(td,"reads1.fastq")
reads_merged_2 <- file.path(td,"reads2.fastq")
atacproc <- 
atacUnzipAndMerge(fastqInput1 = reads_1,fastqInput2 = reads_2) %>%
atacRenamer %>% atacRemoveAdapter

## ----adrmhelp------------------------------------------------------------
library(Rbowtie2)
adapterremoval_usage()

## ----Mapping, warning = FALSE, results = 'hide', message = FALSE---------
## Building a bowtie2 index
library("Rbowtie2")
refs <- dir(system.file(package="esATAC", "extdata", "bt2","refs"),
full=TRUE)
bowtie2_build(references=refs, bt2Index=file.path(td, "lambda_virus"),
"--threads 4 --quiet",overwrite=TRUE)
## Alignments
reads_1 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_1.fastq")
reads_2 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_2.fastq")
if(file.exists(file.path(td, "lambda_virus.1.bt2"))){
    (bowtie2Mapping(bt2Idx = file.path(td, "lambda_virus"),
       samOutput = file.path(td, "result.sam"),
       fastqInput1=reads_1,fastqInput2=reads_2,threads=3))
    head(readLines(file.path(td, "result.sam")))
}

## ----bt2help-------------------------------------------------------------
library(Rbowtie2)
bowtie2_usage()

## ----Convert, warning = FALSE, results = 'hide', message = FALSE---------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBed(samInput = samfile) 

## ----FiltCalling, warning = FALSE, results = 'hide', message = FALSE-----
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling


## ----echo = TRUE, results = 'hide', message = FALSE----------------------
## extract example peak file from package "esATAC"
p1bz <- system.file("extdata", "Example_peak1.bed.bz2", package="esATAC")
peak1_path <- as.vector(bunzip2(filename = p1bz,
destname = file.path(getwd(), "Example_peak1.bed"),
ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
## run peakanno to annotate peaks
AnnoInfo <- peakanno(peakInput = peak1_path, TxDb = TxDb.Hsapiens.UCSC.hg19.knownGene, annoDb = "org.Hs.eg.db")

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
library(ChIPseeker)

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
peakanno <- getReportVal(AnnoInfo, "annoOutput.rds")
plotAnnoPie(x = peakanno)

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
peakanno <- as.data.frame(peakanno)
colnames(peakanno)[1] <- "chromatin"
peakanno <- subset(peakanno, select=c("chromatin", "start", "end", 
                                      "annotation", "geneStart", "geneEnd", 
                                      "geneId", "distanceToTSS", "SYMBOL"))
knitr::kable(peakanno[1:5, ])

## ----eval = TRUE, echo = TRUE, results = 'hide', message = FALSE---------
## extract gene ID
library(clusterProfiler)
data(geneList)
geneId <- names(geneList)[1:100]
## do GO analysis
goAna <- goanalysis(gene = geneId, OrgDb = "org.Hs.eg.db", keytype = "ENTREZID", ont = "MF")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
go_path <- getReportVal(goAna, "goOutput")
go_data <- read.table(file = go_path, header = TRUE, sep = "\t")
go_data <- subset(go_data, select = c("ID", "Description", "GeneRatio", "pvalue", "qvalue"))
knitr::kable(go_data[1:5, ])

## ----eval=TRUE, echo=TRUE, warning=FALSE---------------------------------
pwm <- readRDS(system.file("extdata", "motifPWM.rds", package="esATAC"))

pwm

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  sample.path <- system.file("extdata", "chr20_sample_peak.bed.bz2", package="esATAC")
#  sample.path <- as.vector(bunzip2(filename = sample.path,
#  destname = file.path(getwd(), "chr20_sample_peak.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  motif.data <- motifscan(peak = sample.path, genome = BSgenome.Hsapiens.UCSC.hg19,
#  motifPWM = pwm, prefix = "test")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
CTCF.df <- data.frame(chromatin = c("chr20", "chr20", "chr20", "chr20"),
                      start = c("189774", "239773", "247783", "281074"), 
                      end = c("189792", "239791", "247801", "281092"), 
                      strand = c("+", "+", "-", "-"),
                      score = c("0.8794931", "0.9003697", "0.9337214", "0.8511201"), 
                      sequence = c("ACTCCTCTAGAGGGTGCTC", "TTGCCACTGGGGGGAGACA",
                      "CTGCCGGCAGATGGCGGTA", "TTGCCTGCAGGGGTGGGAA"))
knitr::kable(CTCF.df)

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  ## extract cut site position from bed file
#  fra_path <- system.file("extdata", "chr20.50000.bed.bz2", package="esATAC")
#  frag <- as.vector(bunzip2(filename = fra_path,
#  destname = file.path(getwd(), "chr20.50000.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  cs.data <- extractcutsite(bedInput = frag, prefix = "ATAC")

## ----eval=FALSE, echo=TRUE, warning=FALSE, results='hide', message=FALSE----
#  fp <- atacCutSiteCount(atacProcCutSite = cs.data, atacProcMotifScan = motif.data)

## ----printmap, warning=FALSE, message=FALSE------------------------------
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

peakproc <-bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling 

peakproc %>%  printMap


## ----qpara, warning=FALSE, message=FALSE---------------------------------
#query all of available parameters
getParamItems(peakproc)

## ----getpara, warning=FALSE, message=FALSE-------------------------------
#query a parameter value
getParam(peakproc,"fragmentSize")


## ----getReport, warning=FALSE, results='hide', message=FALSE-------------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBedProc<-samToBed(samInput = samfile)

## ----getReport1,message=FALSE--------------------------------------------
getReportItems(samToBedProc)

## ----getReport2,message=FALSE--------------------------------------------
#query a parameter value
getReportVal(samToBedProc,"report")


## ----clearcache, warning=FALSE, results='hide', message=FALSE------------
clearProcCache(peakproc)
process(peakproc)

## ----session-------------------------------------------------------------
sessionInfo()
